==> maven-resolver-1.9.1-source-release.zip: maven-resolver-1.9.1/maven-resolver-named-locks-hazelcast/src/main/java/org/eclipse/aether/named/hazelcast/DirectHazelcastSemaphoreProvider.java <==
package org.eclipse.aether.named.hazelcast;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import com.hazelcast.core.HazelcastInstance;
import com.hazelcast.cp.ISemaphore;

/**
 * Direct provider of {@link ISemaphore} instances: it simply uses the passed in lock name to create semaphore name out
 * of it. This implies, that as many lock names are requested from it, this class will create as many semaphores in
 * Hazelcast.
 */
public class DirectHazelcastSemaphoreProvider extends HazelcastSemaphoreProvider
{
    @Override
    public ISemaphore acquireSemaphore( HazelcastInstance hazelcastInstance, String name )
    {
        return hazelcastInstance.getCPSubsystem().getSemaphore( NAME_PREFIX + name );
    }

    @Override
    public void releaseSemaphore( HazelcastInstance hazelcastInstance, String name, ISemaphore semaphore )
    {
        // nothing
    }
}

==> maven-resolver-1.9.7-source-release.zip: maven-resolver-1.9.7/maven-resolver-named-locks-hazelcast/src/main/java/org/eclipse/aether/named/hazelcast/DirectHazelcastSemaphoreProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.eclipse.aether.named.hazelcast;

import com.hazelcast.core.HazelcastInstance;
import com.hazelcast.cp.ISemaphore;

/**
 * Direct provider of {@link ISemaphore} instances: it simply uses the passed in lock name to create semaphore name out
 * of it. This implies, that as many lock names are requested from it, this class will create as many semaphores in
 * Hazelcast.
 */
public class DirectHazelcastSemaphoreProvider extends HazelcastSemaphoreProvider {
    @Override
    public ISemaphore acquireSemaphore(HazelcastInstance hazelcastInstance, String name) {
        return hazelcastInstance.getCPSubsystem().getSemaphore(NAME_PREFIX + name);
    }

    @Override
    public void releaseSemaphore(HazelcastInstance hazelcastInstance, String name, ISemaphore semaphore) {
        // nothing
    }
}
